==> jc-1.4.0.tar.gz: java/security/cert/CollectionCertStoreParameters.h <==
// public class java.security.cert.CollectionCertStoreParameters

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 1edbf522b85c12d0 java_security_cert_CollectionCertStoreParameters

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_cert_CollectionCertStoreParameters_H_
#define _JC_java_security_cert_CollectionCertStoreParameters_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Collection$object;

// Typedefs
typedef struct _jc_java_security_cert_CollectionCertStoreParameters$sub_refs	_jc_java_security_cert_CollectionCertStoreParameters$sub_refs;
typedef struct _jc_java_security_cert_CollectionCertStoreParameters$sub_nonrefs	_jc_java_security_cert_CollectionCertStoreParameters$sub_nonrefs;
typedef struct _jc_java_security_cert_CollectionCertStoreParameters$refs	_jc_java_security_cert_CollectionCertStoreParameters$refs;
typedef struct _jc_java_security_cert_CollectionCertStoreParameters$nonrefs	_jc_java_security_cert_CollectionCertStoreParameters$nonrefs;
typedef struct _jc_java_security_cert_CollectionCertStoreParameters$object	_jc_java_security_cert_CollectionCertStoreParameters$object;

typedef const struct _jc_java_security_cert_CollectionCertStoreParameters$vmethods	_jc_java_security_cert_CollectionCertStoreParameters$vmethods;
typedef const struct _jc_java_security_cert_CollectionCertStoreParameters$vtable	_jc_java_security_cert_CollectionCertStoreParameters$vtable;
typedef const struct _jc_java_security_cert_CollectionCertStoreParameters$vtype	_jc_java_security_cert_CollectionCertStoreParameters$vtype;

// Constructors
extern void _jc_java_security_cert_CollectionCertStoreParameters$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_security_cert_CollectionCertStoreParameters$object *);
extern void _jc_java_security_cert_CollectionCertStoreParameters$method$_init$f10d3ead4f9e91ce(_jc_env *, struct _jc_java_security_cert_CollectionCertStoreParameters$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_java_security_cert_CollectionCertStoreParameters$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_java_security_cert_CollectionCertStoreParameters$object *);
extern struct _jc_object *_jc_java_security_cert_CollectionCertStoreParameters$method$getCollection$7d49b679b32f6aa1(_jc_env *, struct _jc_java_security_cert_CollectionCertStoreParameters$object *);
extern struct _jc_java_lang_String$object *_jc_java_security_cert_CollectionCertStoreParameters$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_security_cert_CollectionCertStoreParameters$object *);

// Virtual method descriptors
extern _jc_method _jc_java_security_cert_CollectionCertStoreParameters$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_java_security_cert_CollectionCertStoreParameters$method_info$getCollection$7d49b679b32f6aa1;
extern _jc_method _jc_java_security_cert_CollectionCertStoreParameters$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_security_cert_CollectionCertStoreParameters$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_java_security_cert_CollectionCertStoreParameters$object *);
	struct _jc_object	*(*getCollection$7d49b679b32f6aa1)(_jc_env *, struct _jc_java_security_cert_CollectionCertStoreParameters$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_security_cert_CollectionCertStoreParameters$object *);
};

// Vtable
struct _jc_java_security_cert_CollectionCertStoreParameters$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_cert_CollectionCertStoreParameters$vmethods	java_security_cert_CollectionCertStoreParameters;
};

// Vtype
struct _jc_java_security_cert_CollectionCertStoreParameters$vtype {
	_jc_type			type;
	_jc_java_security_cert_CollectionCertStoreParameters$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_cert_CollectionCertStoreParameters$sub_refs {
	struct _jc_object	*collection;
};

// Reference instance fields (object)
struct _jc_java_security_cert_CollectionCertStoreParameters$refs {
    _jc_java_security_cert_CollectionCertStoreParameters$sub_refs	java_security_cert_CollectionCertStoreParameters;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_cert_CollectionCertStoreParameters$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_cert_CollectionCertStoreParameters$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_cert_CollectionCertStoreParameters$sub_nonrefs	java_security_cert_CollectionCertStoreParameters;
};

// Object instance structure
struct _jc_java_security_cert_CollectionCertStoreParameters$object {
	_jc_java_security_cert_CollectionCertStoreParameters$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_cert_CollectionCertStoreParameters$vtype	*vtype;
	_jc_java_security_cert_CollectionCertStoreParameters$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_cert_CollectionCertStoreParameters$vtype _jc_java_security_cert_CollectionCertStoreParameters$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_cert_CollectionCertStoreParameters, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_cert_CollectionCertStoreParameters$class_object;

#endif	/* _JC_java_security_cert_CollectionCertStoreParameters_H_ */

==> jc-1.4.6.tar.gz: java/security/cert/CollectionCertStoreParameters.h <==
// public class java.security.cert.CollectionCertStoreParameters

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 1edbf522b85c12d0 java_security_cert_CollectionCertStoreParameters

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_cert_CollectionCertStoreParameters_H_
#define _JC_java_security_cert_CollectionCertStoreParameters_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Collection$object;

// Typedefs
typedef struct _jc_java_security_cert_CollectionCertStoreParameters$sub_refs	_jc_java_security_cert_CollectionCertStoreParameters$sub_refs;
typedef struct _jc_java_security_cert_CollectionCertStoreParameters$sub_nonrefs	_jc_java_security_cert_CollectionCertStoreParameters$sub_nonrefs;
typedef struct _jc_java_security_cert_CollectionCertStoreParameters$refs	_jc_java_security_cert_CollectionCertStoreParameters$refs;
typedef struct _jc_java_security_cert_CollectionCertStoreParameters$nonrefs	_jc_java_security_cert_CollectionCertStoreParameters$nonrefs;
typedef struct _jc_java_security_cert_CollectionCertStoreParameters$object	_jc_java_security_cert_CollectionCertStoreParameters$object;

typedef const struct _jc_java_security_cert_CollectionCertStoreParameters$vmethods	_jc_java_security_cert_CollectionCertStoreParameters$vmethods;
typedef const struct _jc_java_security_cert_CollectionCertStoreParameters$vtable	_jc_java_security_cert_CollectionCertStoreParameters$vtable;
typedef const struct _jc_java_security_cert_CollectionCertStoreParameters$vtype	_jc_java_security_cert_CollectionCertStoreParameters$vtype;

// Constructors
extern void _jc_java_security_cert_CollectionCertStoreParameters$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_security_cert_CollectionCertStoreParameters$object *) _JC_JCNI_ATTR;
extern void _jc_java_security_cert_CollectionCertStoreParameters$method$_init$f10d3ead4f9e91ce(_jc_env *, struct _jc_java_security_cert_CollectionCertStoreParameters$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_java_security_cert_CollectionCertStoreParameters$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_java_security_cert_CollectionCertStoreParameters$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_security_cert_CollectionCertStoreParameters$method$getCollection$7d49b679b32f6aa1(_jc_env *, struct _jc_java_security_cert_CollectionCertStoreParameters$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_security_cert_CollectionCertStoreParameters$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_security_cert_CollectionCertStoreParameters$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_security_cert_CollectionCertStoreParameters$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_java_security_cert_CollectionCertStoreParameters$method_info$getCollection$7d49b679b32f6aa1;
extern _jc_method _jc_java_security_cert_CollectionCertStoreParameters$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_security_cert_CollectionCertStoreParameters$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_java_security_cert_CollectionCertStoreParameters$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getCollection$7d49b679b32f6aa1)(_jc_env *, struct _jc_java_security_cert_CollectionCertStoreParameters$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_security_cert_CollectionCertStoreParameters$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_security_cert_CollectionCertStoreParameters$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_cert_CollectionCertStoreParameters$vmethods	java_security_cert_CollectionCertStoreParameters;
};

// Vtype
struct _jc_java_security_cert_CollectionCertStoreParameters$vtype {
	_jc_type			type;
	_jc_java_security_cert_CollectionCertStoreParameters$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_cert_CollectionCertStoreParameters$sub_refs {
	struct _jc_object	*collection;
};

// Reference instance fields (object)
struct _jc_java_security_cert_CollectionCertStoreParameters$refs {
    _jc_java_security_cert_CollectionCertStoreParameters$sub_refs	java_security_cert_CollectionCertStoreParameters;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_cert_CollectionCertStoreParameters$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_cert_CollectionCertStoreParameters$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_cert_CollectionCertStoreParameters$sub_nonrefs	java_security_cert_CollectionCertStoreParameters;
};

// Object instance structure
struct _jc_java_security_cert_CollectionCertStoreParameters$object {
	_jc_java_security_cert_CollectionCertStoreParameters$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_cert_CollectionCertStoreParameters$vtype	*vtype;
	_jc_java_security_cert_CollectionCertStoreParameters$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_cert_CollectionCertStoreParameters$vtype _jc_java_security_cert_CollectionCertStoreParameters$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_cert_CollectionCertStoreParameters, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_cert_CollectionCertStoreParameters$class_object;

#endif	/* _JC_java_security_cert_CollectionCertStoreParameters_H_ */
